@@ -1,9 +1,9 @@
-# -*- mode: cperl; coding: latin-2 -*-
+# -*- mode: cperl -*-
 
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2006,2007,2008,2009 Slaven Rezic. All rights reserved.
+# Copyright (C) 2006,2007,2008,2009,2010 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -19,7 +19,7 @@ use base qw(Exporter);
 use vars qw(@EXPORT_OK $VERSION);
 @EXPORT_OK = qw(validate);
 
-$VERSION = '1.21';
+$VERSION = '1.22';
 
 BEGIN {
     if ($] < 5.006) {
@@ -77,6 +77,7 @@ sub _validate {
 
 sub _additional_rules {
     my($self, $schema, $data, $path) = @_;
+    no warnings 'uninitialized'; # legal undef values may happen everywhere
     for my $schema_key (keys %$schema) {
 	if (defined $schema->{$schema_key}) {
 	    if ($schema_key eq 'pattern') {
@@ -118,7 +119,6 @@ sub _additional_rules {
 		if (!UNIVERSAL::isa($schema->{enum}, 'ARRAY')) {
 		    $self->_die("'enum' must be an array");
 		}
-		no warnings 'uninitialized'; # undef amongst the enum values may be intended!
 		my %valid = map { ($_,1) } @{ $schema->{enum} };
 		if (!exists $valid{$data}) {
 		    $self->_error("'$data': invalid " . _base_path($path) . " value");
@@ -415,8 +415,6 @@ sub _get_boolean {
 1;
 __END__
 
-=encoding iso-8859-2
-
 =head1 NAME
 
 Kwalify - Kwalify schema for data structures
@@ -544,11 +542,11 @@ show a path-like expression to the data causing the error.
 
 =head1 AUTHOR
 
-Slaven Rezi, E<lt>srezic@cpan.orgE<gt>
+Slaven ReziE<x0107>, E<lt>srezic@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006,2007,2008,2009 by Slaven Rezi
+Copyright (C) 2006,2007,2008,2009,2010 by Slaven ReziE<x0107>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
